{% set page = 'about' %}{% include "_header.html" %}

{% set sects = load_rst("README.rst") %}

{#      need api for keywords yea?     #}
{% set api = load_module('context') %}

{% do keywords(api, 'jinja24doc_api.html', types = ('class','function')) %}

{% include "_text.html" %}
{% include "_footer.html" %}
