# -*- coding: utf-8 -*-
"""
    Jinja24doc is lightweight documentation generator for python modules with
    jinja2 templates. It is part of *Poor Http* group tools (WSGI connector,
    WSGI/HTTP Server and mod_python connector). It could load modules and gets
    documentation for its items. No configuration is needed, only jinja2
    templates. Your or from jinja2doc package.
"""

__author__ = "Ondřej Tůma (McBig) <mcbig@zeropage.cz>"
__date__ = "29 Jul 2019"
__version__ = "1.3.3"
