      <div class="footer">
        <div class="line"></div>
        <div class="credit">
            Create by Ondřej Tůma (<a href="http://ipv6.mcbig.cz">McBig</a>).
            &copy; 2013. Generate by
            <a href="http://poorhttp.zeropage.cz/jinja24doc.html">Jinja24doc</a>.
        </div>
      </div><!-- footer --!>
    </div><!-- page --!>
  </body>
</html>
