{% if title is not defined %}
  {% for type, name, args, doc in sections %}
    {% if type == 'text' %}
      {% set title = name %}
      {% include "_header.html" %}
      {% break %}
    {% endif %}
  {% endfor %}
{% else %}
{% include "_header.html" %}
{% endif %}

      <menu class="sidebar">
      {% for type, name, id, doc in sections %}
        {% if type == 'h2' %}<h2><a href="#{{ id }}">{{ name }}</a></h2>
        {% elif type == 'h3' %}<h3><a href="#{{ id }}">{{ name }}</a></h3>
        {% endif %}
      {% endfor %}
      </menu>

      <div class="content">
      {% for type, name, args, doc in sections %}
        {% if type == 'text' %}
        {{ doc }}
        {% endif %}
      {% endfor %}
      </div>

{% include "_footer.html" -%}
